@@ -21,10 +21,12 @@
 #ifndef ANIMATIONRESULTITEM_H
 #define ANIMATIONRESULTITEM_H
 
-#include "imageresultitem.h"
+#include "resultitem.h"
+#include "worksheetimageitem.h"
 
-#include <QMovie>
+class QMovie;
 
+class CommandEntry;
 class WorksheetEntry;
 
 class AnimationResultItem : public WorksheetImageItem, public ResultItem
@@ -32,25 +34,20 @@ class AnimationResultItem : public WorksheetImageItem, public ResultItem
   Q_OBJECT
 
   public:
-    AnimationResultItem(QGraphicsObject* parent);
-    ~AnimationResultItem() override;
+    explicit AnimationResultItem(QGraphicsObject* parent, Cantor::Result* result);
+    ~AnimationResultItem() override = default;
 
     using WorksheetImageItem::setGeometry;
-    double setGeometry(double x, double y, double w) Q_DECL_OVERRIDE;
-    void populateMenu(QMenu* menu, QPointF pos) Q_DECL_OVERRIDE;
+    double setGeometry(double x, double y, double w) override;
+    void populateMenu(QMenu* menu, QPointF pos) override;
 
-    ResultItem* updateFromResult(Cantor::Result*) Q_DECL_OVERRIDE;
+    void update() override;
 
-    void deleteLater() Q_DECL_OVERRIDE;
+    void deleteLater() override;
 
-    QRectF boundingRect() const Q_DECL_OVERRIDE;
-    double width() const Q_DECL_OVERRIDE;
-    double height() const Q_DECL_OVERRIDE;
-    CommandEntry* parentEntry();
-    Cantor::Result* result() Q_DECL_OVERRIDE;
-
-  Q_SIGNALS:
-    void removeResult();
+    QRectF boundingRect() const override;
+    double width() const override;
+    double height() const override;
 
   protected Q_SLOTS:
     void saveResult();
