@@ -27,11 +27,11 @@ class ImportPackageAssistant : public Cantor::Assistant
 {
   public:
     ImportPackageAssistant( QObject* parent, QList<QVariant> args );
-    ~ImportPackageAssistant() override;
+    ~ImportPackageAssistant() override = default;
 
-    void initActions() Q_DECL_OVERRIDE;
+    void initActions() override;
 
-    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
+    QStringList run(QWidget* parentt) override;
 
 };
 
