@@ -35,58 +35,47 @@
 #include <QStringList>
 #include <QTextDocument>
 
-RExpression::RExpression( Cantor::Session* session ) : Cantor::Expression(session)
-{
-
-}
-
-RExpression::~RExpression()
+RExpression::RExpression( Cantor::Session* session, bool internal ) : Cantor::Expression(session, internal),
+m_isHelpRequest(false)
 {
 
 }
 
 void RExpression::evaluate()
 {
-    setStatus(Cantor::Expression::Computing);
     if(command().startsWith(QLatin1Char('?')))
         m_isHelpRequest=true;
     else
         m_isHelpRequest=false;
 
-    static_cast<RSession*>(session())->queueExpression(this);
+    session()->enqueueExpression(this);
 }
 
 void RExpression::interrupt()
 {
     qDebug()<<"interrupting command";
-    if(status()==Cantor::Expression::Computing)
-        session()->interrupt();
     setStatus(Cantor::Expression::Interrupted);
 }
 
 void RExpression::finished(int returnCode, const QString& text)
 {
+    if (status() == Expression::Interrupted)
+        return;
+
     if(returnCode==RExpression::SuccessCode)
     {
-        QString resultString = Qt::convertFromPlainText(text);
-        resultString.chop(5); // Remove <br>\n from end
-        setResult(new Cantor::TextResult(resultString));
+        qDebug() << "text: " << text;
+        setResult(new Cantor::TextResult(text));
         setStatus(Cantor::Expression::Done);
     }else if (returnCode==RExpression::ErrorCode)
     {
-        QString resultString = Qt::convertFromPlainText(text);
-        resultString.chop(5); // Remove <br>\n from end
-        setResult(new Cantor::TextResult(resultString));
+        qDebug() << "text: " << text;
+        //setResult(new Cantor::TextResult(text));
+        setErrorMessage(text);
         setStatus(Cantor::Expression::Error);
-        setErrorMessage(resultString);
     }
 }
 
-void RExpression::evaluationStarted()
-{
-    setStatus(Cantor::Expression::Computing);
-}
-
 void RExpression::addInformation(const QString& information)
 {
     static_cast<RSession*>(session())->sendInputToServer(information);
@@ -107,7 +96,7 @@ void RExpression::showFilesAsResult(const QStringList& files)
             qDebug()<<"its PostScript";
             setResult(new Cantor::EpsResult(QUrl::fromLocalFile(file)));
         }
-        else if(type.inherits(QLatin1String("text/plain")) 
+        else if(type.inherits(QLatin1String("text/plain"))
             || type.inherits(QLatin1String("application/x-extension-html")))
         {
             //Htmls are also plain texts, combining this in one
@@ -132,10 +121,6 @@ void RExpression::showFilesAsResult(const QStringList& files)
                 content.replace( QLatin1Char(' '), QLatin1String("&nbsp;"));
                 //replace appearing backspaces, as they mess the whole output up
                 content.remove(QRegExp(QLatin1String(".\b")));
-                //Replace <, > and & with their html code, so they won't be confused as html tags
-                content.replace( QLatin1Char('<') ,  QLatin1String("&lt;"));
-                content.replace( QLatin1Char('>') ,  QLatin1String("&gt;"));
-                content.replace( QLatin1Char('&') ,  QLatin1String("&amp;"));
             }
 
             qDebug()<<"content: "<<content;
@@ -143,17 +128,16 @@ void RExpression::showFilesAsResult(const QStringList& files)
                 setResult(new Cantor::HelpResult(content));
             else
                 setResult(new Cantor::TextResult(content));
-	    setStatus(Cantor::Expression::Done);
+            setStatus(Cantor::Expression::Done);
         }else if (type.name().contains(QLatin1String("image")))
         {
             setResult(new Cantor::ImageResult(QUrl::fromLocalFile(file)));
-	    setStatus(Cantor::Expression::Done);
+            setStatus(Cantor::Expression::Done);
         }
         else
         {
             // File has unsupported mime type, but we suspect, that it is text, so will open the file in Cantor script editor
             // Even if it don't text, the script editor can deals with it.
-            setResult(new Cantor::TextResult(QLatin1String("")));
             setStatus(Cantor::Expression::Done);
             const QString& editor = QStandardPaths::findExecutable(QLatin1String("cantor_scripteditor"));
             int code = QProcess::execute(editor, QStringList(file));
@@ -164,4 +148,3 @@ void RExpression::showFilesAsResult(const QStringList& files)
         }
     }
 }
-
