@@ -38,35 +38,33 @@ class RSession : public Cantor::Session
 {
   Q_OBJECT
   public:
-    RSession( Cantor::Backend* backend);
-    ~RSession();
+    explicit RSession( Cantor::Backend* backend);
+    ~RSession() override;
 
     void login() override;
     void logout() override;
 
     void interrupt() override;
 
-    Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave) override;
+    Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave = Cantor::Expression::FinishingBehavior::DoNotDelete, bool internal = false) override;
     Cantor::CompletionObject* completionFor(const QString& command, int index=-1) override;
     QSyntaxHighlighter* syntaxHighlighter(QObject* parent) override;
-    QAbstractItemModel* variableModel() Q_DECL_OVERRIDE;
-
-    void queueExpression(RExpression* expr);
+    QAbstractItemModel* variableModel() override;
     void sendInputToServer(const QString& input);
+    void runFirstExpression() override;
 
   protected Q_SLOTS:
     void serverChangedStatus(int status);
-    void runNextExpression();
     void receiveSymbols(const QStringList& vars, const QStringList& values, const QStringList & funcs);
     void fillSyntaxRegExps(QVector<QRegExp>& v, QVector<QRegExp>& f);
 
   Q_SIGNALS:
     void symbolsChanged();
+    void syntaxRegExpsFilled();
 
   private:
     QProcess* m_process;
     org::kde::Cantor::R* m_rServer;
-    QList<RExpression*> m_expressionQueue;
 
     /* Available variables and functions, TODO make full classes and type info */
     Cantor::DefaultVariableModel* m_variableModel;
