@@ -28,11 +28,10 @@
 #include <QTemporaryFile>
 #include <QDebug>
 
-QStringList JuliaServer::INTERNAL_VARIABLES = 
+QStringList JuliaServer::INTERNAL_VARIABLES =
     QStringList() << QLatin1String("__originalSTDOUT__") << QLatin1String("__originalSTDERR__");
 
-JuliaServer::JuliaServer(QObject *parent)
-    : QObject(parent)
+JuliaServer::JuliaServer(QObject *parent) : QObject(parent), m_was_exception(false)
 {
 }
 
@@ -61,7 +60,7 @@ void JuliaServer::login(const QString &path) const
 #endif
 void JuliaServer::runJuliaCommand(const QString &command)
 {
-    // Redirect stdout, stderr to temprorary files
+    // Redirect stdout, stderr to temporary files
     QTemporaryFile output, error;
     if (!output.open() || !error.open()) {
         qFatal("Unable to create temporary files for stdout/stderr");
