@@ -37,9 +37,9 @@ class JuliaServer: public QObject
 {
     Q_OBJECT
 public:
-    JuliaServer(QObject *parent = nullptr);
+    explicit JuliaServer(QObject *parent = nullptr);
 
-    virtual ~JuliaServer();
+    ~JuliaServer() override;
 
 public Q_SLOTS:
     /**
@@ -63,7 +63,7 @@ public Q_SLOTS:
     Q_SCRIPTABLE QString getOutput() const;
 
     /**
-     * @return stderr output of the last command exection
+     * @return stderr output of the last command execution
      */
     Q_SCRIPTABLE QString getError() const;
 
@@ -84,7 +84,7 @@ public Q_SLOTS:
     Q_SCRIPTABLE QStringList variablesList();
 
     /**
-     * @return corresponding list of values for variables from variablesList. 
+     * @return corresponding list of values for variables from variablesList.
      */
     Q_SCRIPTABLE QStringList variableValuesList();
 
