@@ -46,7 +46,7 @@ public:
      *
      * @param backend owning backend
      */
-    JuliaSession(Cantor::Backend *backend);
+    explicit JuliaSession(Cantor::Backend *backend);
 
     /**
      * @see Cantor::Session::login
@@ -68,7 +68,8 @@ public:
      */
     Cantor::Expression *evaluateExpression(
         const QString &command,
-        Cantor::Expression::FinishingBehavior behave) override;
+        Cantor::Expression::FinishingBehavior behave = Cantor::Expression::FinishingBehavior::DoNotDelete,
+        bool internal = false) override;
 
     /**
      * @see Cantor::Session::completionFor
@@ -163,7 +164,7 @@ private:
     QString getError();
 
     /**
-     * @return indicator of exception occured during the last command execution
+     * @return indicator of exception occurred during the last command execution
      */
     bool getWasException();
 
