@@ -16,9 +16,10 @@
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/
 
+#include "kalgebrasession.h"
+
 #include "settings.h"
 
-#include "kalgebrasession.h"
 #include "kalgebraexpression.h"
 #include "kalgebracompletionobject.h"
 #include <analitzagui/algebrahighlighter.h>
@@ -50,7 +51,7 @@ void KAlgebraSession::login()
     if(!KAlgebraSettings::autorunScripts().isEmpty()){
         QString autorunScripts = KAlgebraSettings::self()->autorunScripts().join(QLatin1String("\n"));
 
-        evaluateExpression(autorunScripts, KAlgebraExpression::DeleteOnFinish);
+        evaluateExpression(autorunScripts, KAlgebraExpression::DeleteOnFinish, true);
     }
 
     changeStatus(Cantor::Session::Done);
@@ -58,7 +59,9 @@ void KAlgebraSession::login()
 }
 
 void KAlgebraSession::logout()
-{}
+{
+    changeStatus(Status::Disable);
+}
 
 void KAlgebraSession::interrupt()
 {
@@ -66,9 +69,10 @@ void KAlgebraSession::interrupt()
 }
 
 Cantor::Expression* KAlgebraSession::evaluateExpression(const QString& cmd,
-                                                        Cantor::Expression::FinishingBehavior behave)
+                                                        Cantor::Expression::FinishingBehavior behave,
+                                                        bool internal)
 {
-    KAlgebraExpression* expr=new KAlgebraExpression(this);
+    KAlgebraExpression* expr=new KAlgebraExpression(this, internal);
     expr->setFinishingBehavior(behave);
 
     changeStatus(Cantor::Session::Running);
@@ -101,7 +105,7 @@ QSyntaxHighlighter* KAlgebraSession::syntaxHighlighter(QObject* parent)
     Q_UNUSED(parent);
     //return new AlgebraHighlighter(parent->document());
     // TODO: Think of something better here.
-    return new AlgebraHighlighter(NULL);
+    return new AlgebraHighlighter(nullptr);
 }
 
 QAbstractItemModel* KAlgebraSession::variableModel()
