@@ -24,29 +24,43 @@
 
 #include "luasession.h"
 #include "luahelper.h"
+#include "luakeywords.h"
 
 LuaCompletionObject::LuaCompletionObject(const QString& command, int index, LuaSession* session)
-    : Cantor::CompletionObject(session), m_L(session->getState())
+    : Cantor::CompletionObject(session)
 {
+    if (session->status() != Cantor::Session::Disable)
+        m_L = session->getState();
+    else
+        m_L = nullptr;
     setLine(command, index);
 }
 
-LuaCompletionObject::~LuaCompletionObject()
-{
-
-}
-
 void LuaCompletionObject::fetchCompletions()
 {
-    QString name = command();
-    int idx = name.lastIndexOf(QLatin1String("="));
+    if (session()->status() == Cantor::Session::Disable)
+    {
+        QStringList allCompletions;
+        
+        allCompletions << LuaKeywords::instance()->keywords();
+        allCompletions << LuaKeywords::instance()->functions();
+        allCompletions << LuaKeywords::instance()->variables();
 
-    // gets "table.next" from the expression "varname =   table.next"
-    if(idx >= 0)
-        name = name.mid(idx+1).trimmed();
+        setCompletions(allCompletions);
+        emit fetchingDone();
+    }
+    else
+    {
+        QString name = command();
+        int idx = name.lastIndexOf(QLatin1String("="));
 
-    setCompletions( luahelper_completion(m_L, name) );
-    emit fetchingDone();
+        // gets "table.next" from the expression "varname =   table.next"
+        if(idx >= 0)
+            name = name.mid(idx+1).trimmed();
+
+        setCompletions( luahelper_completion(m_L, name) );
+        emit fetchingDone();
+    }
 }
 
 bool LuaCompletionObject::mayIdentifierContain(QChar c) const
