@@ -32,12 +32,8 @@
 #include <QString>
 #include <QStringList>
 
-LuaExpression::LuaExpression( Cantor::Session* session)
-    : Cantor::Expression(session)
-{
-}
-
-LuaExpression::~LuaExpression()
+LuaExpression::LuaExpression( Cantor::Session* session, bool internal)
+    : Cantor::Expression(session, internal)
 {
 }
 
@@ -101,7 +97,8 @@ void LuaExpression::parseOutput(QString &output)
 
     qDebug() << "final output of the command " <<  command() << ": " << parsedOutput << endl;
 
-    setResult(new Cantor::TextResult(parsedOutput));
+    if (!parsedOutput.isEmpty())
+        setResult(new Cantor::TextResult(parsedOutput));
     setStatus(Cantor::Expression::Done);
 }
 
