@@ -19,13 +19,14 @@
  */
 
 #include "luahighlighter.h"
+#include "luakeywords.h"
 #include "luahelper.h"
 
 LuaHighlighter::LuaHighlighter(QObject* parent): DefaultHighlighter(parent)
 {
-    addFunctions( luahelper_functions() );
-    addKeywords ( luahelper_keywords()  );
-    addVariables( luahelper_variables() );
+    addKeywords (LuaKeywords::instance()->keywords());
+    addFunctions(LuaKeywords::instance()->functions());
+    addVariables(LuaKeywords::instance()->variables());
 
     addRule(QRegExp(QLatin1String("[A-Za-z0-9_]+(?=\\()"))    , functionFormat());
     addRule(QRegExp(QLatin1String("\"[^\"]*\""))              , stringFormat());
@@ -33,7 +34,3 @@ LuaHighlighter::LuaHighlighter(QObject* parent): DefaultHighlighter(parent)
     addRule(QRegExp(QLatin1String("--[^\n]*"))                , commentFormat());
     // did not add support for the multiline comment or multiline string
 }
-
-LuaHighlighter::~LuaHighlighter()
-{
-}
