@@ -50,23 +50,25 @@ void TestMaxima::testSimpleCommand()
 
 void TestMaxima::testMultilineCommand()
 {
-    Cantor::Expression* e=evalExp( QLatin1String("2+2;3+3") );
+    Cantor::Expression* e = evalExp( QLatin1String("2+2;3+3") );
 
-    QVERIFY( e!=nullptr );
-    QVERIFY( e->result()!=nullptr );
+    QVERIFY(e != nullptr);
+    QVERIFY(e->results().size() == 2);
 
-    QString result=e->result()->toHtml();
+    QString result = e->results().at(0)->toHtml();
+    QCOMPARE(result, QLatin1String("4"));
 
-    QCOMPARE( cleanOutput(result ), QLatin1String("4\n6") );
+    result = e->results().at(1)->toHtml();
+    QCOMPARE(result, QLatin1String("6"));
 }
 
-//WARNING: for this test to work, Integration of Plots must be anabled
+//WARNING: for this test to work, Integration of Plots must be enabled
 //and CantorLib must be compiled with EPS-support
 void TestMaxima::testPlot()
 {
     if(QStandardPaths::findExecutable(QLatin1String("gnuplot")).isNull())
     {
-        QSKIP("gnuplot not found maxima needs it for plotting", SkipSingle);
+        QSKIP("gnuplot not found, maxima needs it for plotting", SkipSingle);
     }
 
     Cantor::Expression* e=evalExp( QLatin1String("plot2d(sin(x), [x, -10,10])") );
@@ -88,6 +90,35 @@ void TestMaxima::testPlot()
     QVERIFY( e->errorMessage().isNull() );
 }
 
+void TestMaxima::testPlotWithAnotherTextResults()
+{
+    if(QStandardPaths::findExecutable(QLatin1String("gnuplot")).isNull())
+    {
+        QSKIP("gnuplot not found, maxima needs it for plotting", SkipSingle);
+    }
+
+    Cantor::Expression* e=evalExp( QLatin1String(
+        "2*2; \n"
+        "plot2d(sin(x), [x, -10,10]); \n"
+        "4*4;"
+    ));
+
+    QVERIFY( e!=nullptr );
+    QVERIFY( e->errorMessage().isNull() );
+    QCOMPARE(e->results().size(), 3);
+
+    QCOMPARE(e->results()[0]->toHtml(), QLatin1String("4"));
+
+#ifdef WITH_EPS
+    QCOMPARE( e->results()[1]->type(), (int)Cantor::EpsResult::Type );
+#else
+    QCOMPARE( e->results()[1]->type(), (int)Cantor::ImageResult::Type );
+#endif
+    QVERIFY( !e->results()[1]->data().isNull() );
+
+    QCOMPARE(e->results()[2]->toHtml(), QLatin1String("16"));
+}
+
 void TestMaxima::testInvalidSyntax()
 {
     Cantor::Expression* e=evalExp( QLatin1String("2+2*(") );
@@ -105,7 +136,7 @@ void TestMaxima::testExprNumbering()
     int id=e->id();
     QCOMPARE( id, 1 );
 
-    e=evalExp( QString::fromLatin1("%O%1+1" ).arg( id ) );
+    e=evalExp( QString::fromLatin1("%o%1+1" ).arg( id ) );
     QVERIFY( e != nullptr );
     QVERIFY( e->result()!=nullptr );
     QCOMPARE( cleanOutput( e->result()->toHtml() ), QLatin1String( "5" ) );
@@ -174,7 +205,7 @@ void TestMaxima::testInvalidAssignment()
     //QVERIFY(e->status()==Cantor::Expression::Error);
 
     if(session()->status()==Cantor::Session::Running)
-        waitForSignal(session(), SIGNAL( statusChanged(Cantor::Session::Status)));
+        waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
 
     //make sure we didn't screw up the session
     Cantor::Expression* e2=evalExp(QLatin1String("2+2"));
@@ -189,7 +220,7 @@ void TestMaxima::testInformationRequest()
     Cantor::Expression* e=session()->evaluateExpression(QLatin1String("integrate(x^n,x)"));
     QVERIFY(e!=nullptr);
     waitForSignal(e, SIGNAL(needsAdditionalInformation(QString)));
-    e->addInformation(QLatin1String("nonzero;"));
+    e->addInformation(QLatin1String("N"));
 
     waitForSignal(e, SIGNAL(statusChanged(Cantor::Expression::Status)));
     QVERIFY(e->result()!=nullptr);
@@ -204,7 +235,61 @@ void TestMaxima::testSyntaxHelp()
     waitForSignal(help, SIGNAL(done()));
 
     qWarning()<<help->toHtml();
-    QVERIFY(!help->toHtml().isEmpty());
+    QVERIFY(help->toHtml().contains(QLatin1String("simplify_sum")));
+}
+
+void TestMaxima::testHelpRequest()
+{
+    //execute "??print"
+    Cantor::Expression* e = session()->evaluateExpression(QLatin1String("??print"));
+    QVERIFY(e != nullptr);
+
+    //help result will be shown, but maxima still expects further input
+    waitForSignal(e, SIGNAL(needsAdditionalInformation(QString)));
+    QVERIFY(e->status() != Cantor::Expression::Done);
+
+    //ask for help for the first flag of the print command
+    e->addInformation(QLatin1String("0"));
+
+    //no further input is required, we're done
+    waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
+    QVERIFY(e->status() == Cantor::Expression::Done);
+}
+
+void TestMaxima::testVariableModel()
+{
+    QAbstractItemModel* model = session()->variableModel();
+    QVERIFY(model != nullptr);
+
+    Cantor::Expression* e1=evalExp(QLatin1String("a: 15"));
+    Cantor::Expression* e2=evalExp(QLatin1String("a: 15; b: \"Hello, world!\""));
+    Cantor::Expression* e3=evalExp(QLatin1String("l: [1,2,3]"));
+    QVERIFY(e1!=nullptr);
+    QVERIFY(e2!=nullptr);
+    QVERIFY(e3!=nullptr);
+
+    if(session()->status()==Cantor::Session::Running)
+        waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
+
+    QCOMPARE(3, model->rowCount());
+
+    QVariant name = model->index(0,0).data();
+    QCOMPARE(name.toString(),QLatin1String("a"));
+
+    QVariant value = model->index(0,1).data();
+    QCOMPARE(value.toString(),QLatin1String("15"));
+
+    QVariant name1 = model->index(1,0).data();
+    QCOMPARE(name1.toString(),QLatin1String("b"));
+
+    QVariant value1 = model->index(1,1).data();
+    QCOMPARE(value1.toString(),QLatin1String("\"Hello, world!\""));
+
+    QVariant name2 = model->index(2,0).data();
+    QCOMPARE(name2.toString(),QLatin1String("l"));
+
+    QVariant value2 = model->index(2,1).data();
+    QCOMPARE(value2.toString(),QLatin1String("[1,2,3]"));
 }
 
 QTEST_MAIN( TestMaxima )
