@@ -21,10 +21,10 @@
 #define OCTAVEHIGHLIGHTER_H
 
 #include "defaulthighlighter.h"
+#include <session.h>
 
 namespace Cantor
 {
-    class Session;
     class Expression;
 }
 
@@ -34,24 +34,14 @@ class OctaveHighlighter : public Cantor::DefaultHighlighter
 
   public:
     OctaveHighlighter(QObject* parent, Cantor::Session* session);
-    ~OctaveHighlighter() override;
+    ~OctaveHighlighter() override = default;
 
   public Q_SLOTS:
-    void receiveFunctions();
-    void receiveVariables();
-
-    void updateFunctions();
     void updateVariables();
+    void sessionStatusChanged(Cantor::Session::Status status);
 
   private:
     Cantor::Session* m_session;
-    Cantor::Expression* m_functionsExpr;
-    Cantor::Expression* m_varsExpr;
-    bool m_functionsReceived;
-    bool m_variablesReceived;
-
-    QStringList m_operators;
-    QStringList m_keywords;
     QStringList m_variables;
 };
 
