@@ -21,19 +21,20 @@
 #include "octaveexpression.h"
 #include "octavecompletionobject.h"
 #include "octavesyntaxhelpobject.h"
+#include "octavehighlighter.h"
 #include "result.h"
 #include "textresult.h"
 
 #include "settings.h"
 #include "octave-backend-config.h"
+#include "octavehighlighter.h"
 
 #include <KProcess>
 #include <KDirWatch>
+#include <KLocalizedString>
 
 #include <QTimer>
 #include <QFile>
-#include "octavehighlighter.h"
-#include <settings.h>
 
 #ifndef Q_OS_WIN
 #include <signal.h>
@@ -41,20 +42,21 @@
 
 #include <defaultvariablemodel.h>
 
+const QRegExp OctaveSession::PROMPT_UNCHANGEABLE_COMMAND = QRegExp(QLatin1String("(,|;)+"));
+
 OctaveSession::OctaveSession ( Cantor::Backend* backend ) : Session ( backend ),
 m_process(nullptr),
-m_currentExpression(nullptr),
+m_prompt(QLatin1String("CANTOR_OCTAVE_BACKEND_PROMPT:([0-9]+)> ")),
+m_subprompt(QLatin1String("CANTOR_OCTAVE_BACKEND_SUBPROMPT:([0-9]+)> ")),
+m_previousPromptNumber(1),
 m_watch(nullptr),
+m_loginFinish(false),
+m_syntaxError(false),
 m_variableModel(new Cantor::DefaultVariableModel(this))
 {
     qDebug() << octaveScriptInstallDir;
 }
 
-OctaveSession::~OctaveSession()
-{
-
-}
-
 void OctaveSession::login()
 {
     qDebug() << "login";
@@ -66,6 +68,12 @@ void OctaveSession::login()
     args << QLatin1String("--interactive");
     args << QLatin1String("--persist");
 
+    // Setting prompt and subprompt
+    args << QLatin1String("--eval");
+    args << QLatin1String("PS1('CANTOR_OCTAVE_BACKEND_PROMPT:\\#> ');");
+    args << QLatin1String("--eval");
+    args << QLatin1String("PS2('CANTOR_OCTAVE_BACKEND_SUBPROMPT:\\#> ');");
+
     // Add the cantor script directory to search path
     args << QLatin1String("--eval");
     args << QString::fromLatin1("addpath %1;").arg(octaveScriptInstallDir);
@@ -101,9 +109,9 @@ void OctaveSession::login()
 
     // connect the signal and slots prior to staring octave to make sure we handle the very first output
     // in parserOutput() to determine the temp folder and the format of the promt
-    connect ( m_process, SIGNAL ( readyReadStandardOutput() ), SLOT ( readOutput() ) );
-    connect ( m_process, SIGNAL ( readyReadStandardError() ), SLOT ( readError() ) );
-    connect ( m_process, SIGNAL ( error ( QProcess::ProcessError ) ), SLOT ( processError() ) );
+    connect ( m_process, SIGNAL (readyReadStandardOutput()), SLOT (readOutput()) );
+    connect ( m_process, SIGNAL (readyReadStandardError()), SLOT (readError()) );
+    connect ( m_process, SIGNAL (error(QProcess::ProcessError)), SLOT (processError()) );
 
     m_process->setProgram ( OctaveSettings::path().toLocalFile(), args );
     qDebug() << "starting " << m_process->program();
@@ -115,9 +123,10 @@ void OctaveSession::login()
     if(!OctaveSettings::self()->autorunScripts().isEmpty()){
         QString autorunScripts = OctaveSettings::self()->autorunScripts().join(QLatin1String("\n"));
 
-        evaluateExpression(autorunScripts, OctaveExpression::DeleteOnFinish);
+        evaluateExpression(autorunScripts, OctaveExpression::DeleteOnFinish, true);
     }
 
+    changeStatus(Cantor::Session::Done);
     emit loginDone();
     qDebug()<<"login done";
 }
@@ -129,10 +138,10 @@ void OctaveSession::logout()
     if(!m_process)
         return;
 
-    disconnect(m_process, 0, this, 0);
+    disconnect(m_process, nullptr, this, nullptr);
 
-//     if(status()==Cantor::Session::Running)
-        //TODO: terminate the running expressions first
+    // if(status()==Cantor::Session::Running)
+    // TODO: terminate the running expressions first
 
     m_process->write("exit\n");
     qDebug()<<"waiting for octave to finish";
@@ -145,34 +154,54 @@ void OctaveSession::logout()
         qDebug()<<"octave still running, process kill enforced";
     }
 
-    m_expressionQueue.clear();
+    expressionQueue().clear();
     delete m_process;
     m_process = nullptr;
 
-    m_currentExpression = nullptr;
-    m_prompt = QRegExp();
+
     m_tempDir.clear();
+    m_output.clear();
+    m_previousPromptNumber = 1;
+    m_loginFinish = false;
+
+    m_variableModel->clearVariables();
+
+    changeStatus(Status::Disable);
 
     qDebug()<<"logout done";
 }
 
 void OctaveSession::interrupt()
 {
-    qDebug() << "interrupt";
-    if (m_currentExpression)
+    if(!expressionQueue().isEmpty())
     {
-        m_currentExpression->interrupt();
-    }
-    m_expressionQueue.clear();
-    qDebug() << "Sending SIGINT to Octave";
-    // Some commands, like `quit()`, potentially could finish octave process
-    // So, avoiding crash, have make check before call kill, that the process still exist
-    if(m_process->state() != QProcess::NotRunning)
+        qDebug()<<"interrupting " << expressionQueue().first()->command();
+        if(m_process->state() != QProcess::NotRunning)
+        {
 #ifndef Q_OS_WIN
-        kill(m_process->pid(), SIGINT);
+            const int pid=m_process->pid();
+            kill(pid, SIGINT);
 #else
-        ; //TODO: interrupt the process on windows
+            ; //TODO: interrupt the process on windows
 #endif
+        }
+        expressionQueue().first()->interrupt();
+        expressionQueue().removeFirst();
+
+        foreach (Cantor::Expression* expression, expressionQueue())
+            expression->setStatus(Cantor::Expression::Done);
+        expressionQueue().clear();
+
+        // Cleanup inner state and call octave prompt printing
+        // If we move this code for interruption to Session, we need add function for
+        // cleaning before setting Done status
+        m_output.clear();
+        m_process->write("\n");
+
+        qDebug()<<"done interrupting";
+    }
+
+    changeStatus(Cantor::Session::Done);
 }
 
 void OctaveSession::processError()
@@ -181,10 +210,10 @@ void OctaveSession::processError()
     emit error(m_process->errorString());
 }
 
-Cantor::Expression* OctaveSession::evaluateExpression ( const QString& command, Cantor::Expression::FinishingBehavior finishingBehavior )
+Cantor::Expression* OctaveSession::evaluateExpression ( const QString& command, Cantor::Expression::FinishingBehavior finishingBehavior, bool internal )
 {
     qDebug() << "evaluating: " << command;
-    OctaveExpression* expression = new OctaveExpression ( this );
+    OctaveExpression* expression = new OctaveExpression ( this, internal);
     expression->setCommand ( command );
     expression->setFinishingBehavior ( finishingBehavior );
     expression->evaluate();
@@ -192,19 +221,19 @@ Cantor::Expression* OctaveSession::evaluateExpression ( const QString& command,
     return expression;
 }
 
-void OctaveSession::runExpression ( OctaveExpression* expression )
+void OctaveSession::runFirstExpression()
 {
-    qDebug() << "runExpression";
-    if ( status() != Done ) {
-        m_expressionQueue.enqueue ( expression );
-        qDebug() << m_expressionQueue.size();
-    } else {
-        m_currentExpression = expression;
-        changeStatus(Running);
-        connect(m_currentExpression, SIGNAL(statusChanged(Cantor::Expression::Status)), this, SLOT(currentExpressionStatusChanged(Cantor::Expression::Status)));
-        QString command = expression->command();
-        command.replace(QLatin1Char('\n'), QLatin1Char(','));
-        command += QLatin1Char('\n');
+    OctaveExpression* expression = static_cast<OctaveExpression*>(expressionQueue().first());
+    connect(expression, SIGNAL(statusChanged(Cantor::Expression::Status)), this, SLOT(currentExpressionStatusChanged(Cantor::Expression::Status)));
+    QString command = expression->command();
+    command.replace(QLatin1String(";\n"), QLatin1String(";"));
+    command.replace(QLatin1Char('\n'), QLatin1Char(','));
+    command += QLatin1Char('\n');
+    expression->setStatus(Cantor::Expression::Computing);
+    if (isDoNothingCommand(command))
+        expression->setStatus(Cantor::Expression::Done);
+    else
+    {
         m_process->write ( command.toLocal8Bit() );
     }
 }
@@ -213,11 +242,19 @@ void OctaveSession::readError()
 {
     qDebug() << "readError";
     QString error = QString::fromLocal8Bit(m_process->readAllStandardError());
-    if (!m_currentExpression || error.isEmpty())
+    if (!expressionQueue().isEmpty() && !error.isEmpty())
     {
-        return;
+        OctaveExpression* const exp = static_cast<OctaveExpression*>(expressionQueue().first());
+        if (m_syntaxError)
+        {
+            m_syntaxError = false;
+            exp->parseError(i18n("Syntax Error"));
+        }
+        else
+            exp->parseError(error);
+
+        m_output.clear();
     }
-    m_currentExpression->parseError(error);
 }
 
 void OctaveSession::readOutput()
@@ -233,17 +270,11 @@ void OctaveSession::readOutput()
         }
         QString line = QString::fromLocal8Bit(m_process->readLine());
         qDebug()<<"start parsing " << "  " << line;
-        if (!m_currentExpression || m_prompt.isEmpty())
+        if (!m_loginFinish)
         {
-            // no expression is available, we're parsing the first output of octave after the start
-            // -> determine the location of the temporary folder and the format of octave's promt
-            if (m_prompt.isEmpty() && line.contains(QLatin1String(":1>")))
-            {
-                qDebug() << "Found Octave prompt:" << line;
-                line.replace(QLatin1String(":1"), QLatin1String(":[0-9]+"));
-                m_prompt.setPattern(line);
-            }
-            else if (line.contains(QLatin1String("____TMP_DIR____")))
+            // we're parsing the first output of octave after the start
+            // -> determine the location of the temporary folder
+            if (line.contains(QLatin1String("____TMP_DIR____")))
             {
                 m_tempDir = line;
                 m_tempDir.remove(0,18);
@@ -253,56 +284,63 @@ void OctaveSession::readOutput()
                 {
                     m_watch->addDir(m_tempDir, KDirWatch::WatchFiles);
                 }
+                m_loginFinish = true;
             }
         }
         else if (line.contains(m_prompt))
         {
-            // Check for errors before finalizing the expression
-            // this makes sure that all errors are caught
-            readError();
-            m_currentExpression->finalize();
-            if (m_currentExpression->command().contains(QLatin1String(" = ")))
+            const int promptNumber = m_prompt.cap(1).toInt();
+            if (!expressionQueue().isEmpty())
             {
-                emit variablesChanged();
-            }
-            if (m_currentExpression->command().contains(QLatin1String("function ")))
-            {
-                emit functionsChanged();
+                const QString& command = expressionQueue().first()->command();
+                if (m_previousPromptNumber + 1 == promptNumber || isSpecialOctaveCommand(command))
+                {
+                    if (!expressionQueue().isEmpty())
+                    {
+                        if (command.contains(QLatin1String(" = ")) || command.contains(QLatin1String("clear")))
+                        {
+                            emit variablesChanged();
+                        }
+                        static_cast<OctaveExpression*>(expressionQueue().first())->parseOutput(m_output);
+                    }
+                }
+                else
+                {
+                    // Error command don't increase octave prompt number (usually, but not always)
+                    readError();
+                }
             }
+            m_previousPromptNumber = promptNumber;
+            m_output.clear();
+        }
+        else if (line.contains(m_subprompt) && m_subprompt.cap(1).toInt() == m_previousPromptNumber)
+        {
+            // User don't write finished octave statement (for example, write 'a = [1,2, ' only), so
+            // octave print subprompt and waits input finish.
+            m_syntaxError = true;
+            qDebug() << "subprompt catch";
+            m_process->write(")]'\"\n"); // forse exit from subprompt
+            m_output.clear();
         }
         else
-        {
-            // Avoid many calls to setResult if a lot of output came at the same time
-            while (m_process->canReadLine())
-            {
-                line += QString::fromLocal8Bit(m_process->readLine());
-            }
-            m_currentExpression->parseOutput(line);
-
-        }
+            m_output += line;
     }
 }
 
 void OctaveSession::currentExpressionStatusChanged(Cantor::Expression::Status status)
 {
     qDebug() << "currentExpressionStatusChanged";
-    if (!m_currentExpression)
-    {
-        return;
-    }
     switch (status)
     {
-    case Cantor::Expression::Computing:
-        break;
-    case Cantor::Expression::Interrupted:
-        break;
     case Cantor::Expression::Done:
     case Cantor::Expression::Error:
-        changeStatus(Done);
-        if (!m_expressionQueue.isEmpty())
-        {
-            runExpression(m_expressionQueue.dequeue());
-        }
+        expressionQueue().removeFirst();
+        if (expressionQueue().isEmpty())
+            changeStatus(Done);
+        else
+            runFirstExpression();
+        break;
+    default:
         break;
     }
 }
@@ -313,9 +351,10 @@ void OctaveSession::plotFileChanged(const QString& filename)
     {
         return;
     }
-    if (m_currentExpression)
+
+    if (!expressionQueue().isEmpty())
     {
-        m_currentExpression->parsePlotFile(filename);
+        static_cast<OctaveExpression*>(expressionQueue().first())->parsePlotFile(filename);
     }
 }
 
@@ -332,8 +371,10 @@ Cantor::SyntaxHelpObject* OctaveSession::syntaxHelpFor ( const QString& cmd )
 QSyntaxHighlighter* OctaveSession::syntaxHighlighter ( QObject* parent )
 {
     OctaveHighlighter* highlighter = new OctaveHighlighter ( parent, this );
-    connect ( this, SIGNAL(functionsChanged()), highlighter, SLOT(updateFunctions()) );
+
     connect ( this, SIGNAL(variablesChanged()), highlighter, SLOT(updateVariables()) );
+    connect ( this, SIGNAL(statusChanged(Cantor::Session::Status)), highlighter, SLOT(sessionStatusChanged(Cantor::Session::Status)) );
+
     return highlighter;
 }
 
@@ -347,3 +388,13 @@ void OctaveSession::runSpecificCommands()
 {
     m_process->write("figure(1,'visible','off')");
 }
+
+bool OctaveSession::isDoNothingCommand(const QString& command)
+{
+    return PROMPT_UNCHANGEABLE_COMMAND.exactMatch(command) || command.isEmpty();
+}
+
+bool OctaveSession::isSpecialOctaveCommand(const QString& command)
+{
+    return command.contains(QLatin1String("completion_matches"));
+}
