@@ -23,22 +23,23 @@
 
 #include <QDebug>
 
-OctaveSyntaxHelpObject::OctaveSyntaxHelpObject(const QString& command, Cantor::Session* session): SyntaxHelpObject(command, session)
-{
-
-}
-
-OctaveSyntaxHelpObject::~OctaveSyntaxHelpObject()
+OctaveSyntaxHelpObject::OctaveSyntaxHelpObject(const QString& command, Cantor::Session* session): SyntaxHelpObject(command, session),
+m_expression(nullptr)
 {
 
 }
 
 void OctaveSyntaxHelpObject::fetchInformation()
 {
-    qDebug() << "Fetching syntax help for" << command();
-    QString expr = QString::fromLatin1("help('%1')").arg(command());
-    m_expression = session()->evaluateExpression(expr);
-    connect(m_expression, &Cantor::Expression::statusChanged, this, &OctaveSyntaxHelpObject::fetchingDone);
+    if (session()->status() != Cantor::Session::Disable)
+    {
+        qDebug() << "Fetching syntax help for" << command();
+        QString expr = QString::fromLatin1("help('%1')").arg(command());
+        m_expression = session()->evaluateExpression(expr, Cantor::Expression::FinishingBehavior::DoNotDelete, true);
+        connect(m_expression, &Cantor::Expression::statusChanged, this, &OctaveSyntaxHelpObject::fetchingDone);
+    }
+    else
+        emit done();
 }
 
 void OctaveSyntaxHelpObject::fetchingDone()
