@@ -69,6 +69,7 @@ class CANTOR_PYTHONBACKEND_EXPORT PythonSession : public Cantor::Session
     QString DbusChannelName;
 
     QString worksheetPath;
+    int m_pythonVersion;
 
   protected:
     QString m_output;
@@ -99,6 +100,7 @@ class CANTOR_PYTHONBACKEND_EXPORT PythonSession : public Cantor::Session
   Q_SIGNALS:
     void updateHighlighter();
     void newVariable(const QString variable);
+    void clearVariables();
 };
 
 #endif /* _PYTHONSESSION_H */
