@@ -23,28 +23,13 @@
 
 #include "../python/pythonsession.h"
 
-struct _object;
-typedef _object PyObject;
-
 class Python2Session : public PythonSession
 {
   public:
-    Python2Session(Cantor::Backend* backend);
+    explicit Python2Session(Cantor::Backend* backend);
 
-    void login();
-
-    bool integratePlots() const;
-    QStringList autorunScripts() const;
-
-  private:
-    void runPythonCommand(const QString& command) const;
-    QString getOutput() const;
-    QString getError() const;
-
-    QString pyObjectToQString(PyObject* obj) const;
-
-  private:
-    PyObject *m_pModule;
+    bool integratePlots() const override;
+    QStringList autorunScripts() const override;
 };
 
 #endif
