@@ -183,7 +183,7 @@ QString SagePlotExtension::plotFunction2d(const QString& function, const QString
     return QString::fromLatin1("plot(%1,%2,%3,%4)").arg(function, variable, left, right);
 }
 
-QString SagePlotExtension::plotFunction3d(const QString& function, VariableParameter var1, VariableParameter var2)
+QString SagePlotExtension::plotFunction3d(const QString& function, const VariableParameter& var1, const VariableParameter& var2)
 {
     const Interval& int1=var1.second;
     const Interval& int2=var2.second;
