@@ -31,6 +31,10 @@
 #include <KMessageBox>
 #include "settings.h"
 
+#ifndef Q_OS_WIN
+#include <signal.h>
+#endif
+
 const QByteArray SageSession::SagePrompt="sage: "; //Text, sage outputs after each command
 const QByteArray SageSession::SageAlternativePrompt="....: "; //Text, sage outputs when it expects further input
 
@@ -99,15 +103,13 @@ bool SageSession::VersionInfo::operator>=(SageSession::VersionInfo other) const
     return !( *this < other);
 }
 
-SageSession::SageSession(Cantor::Backend* backend) : Session(backend)
-{
-    m_isInitialized=false;
-    m_haveSentInitCmd=false;
-    connect( &m_dirWatch, SIGNAL( created( const QString& ) ), this, SLOT( fileCreated( const QString& ) ) );
-}
-
-SageSession::~SageSession()
+SageSession::SageSession(Cantor::Backend* backend) : Session(backend),
+m_process(nullptr),
+m_isInitialized(false),
+m_waitingForPrompt(false),
+m_haveSentInitCmd(false)
 {
+    connect( &m_dirWatch, SIGNAL(created(QString)), this, SLOT(fileCreated(QString)) );
 }
 
 void SageSession::login()
@@ -134,7 +136,7 @@ void SageSession::login()
 
     connect(m_process->pty(), SIGNAL(readyRead()), this, SLOT(readStdOut()));
     connect(m_process, SIGNAL(readyReadStandardError()), this, SLOT(readStdErr()));
-    connect(m_process, SIGNAL(finished ( int,  QProcess::ExitStatus )), this, SLOT(processFinished(int, QProcess::ExitStatus)));
+    connect(m_process, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(processFinished(int,QProcess::ExitStatus)));
     connect(m_process, SIGNAL(error(QProcess::ProcessError)), this, SLOT(reportProcessError(QProcess::ProcessError)));
     m_process->start();
     m_process->waitForStarted();
@@ -143,9 +145,10 @@ void SageSession::login()
 
     if(!SageSettings::self()->autorunScripts().isEmpty()){
         QString autorunScripts = SageSettings::self()->autorunScripts().join(QLatin1String("\n"));
-        evaluateExpression(autorunScripts, SageExpression::DeleteOnFinish);
+        evaluateExpression(autorunScripts, SageExpression::DeleteOnFinish, true);
     }
 
+    changeStatus(Session::Done);
     emit loginDone();
 }
 
@@ -153,20 +156,22 @@ void SageSession::logout()
 {
     qDebug()<<"logout";
 
-    disconnect(m_process, SIGNAL(finished ( int,  QProcess::ExitStatus )), this, SLOT(processFinished(int, QProcess::ExitStatus)));
+    disconnect(m_process, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(processFinished(int,QProcess::ExitStatus)));
     m_process->pty()->write("exit\n");
 
     m_process->kill();
     //Run sage-cleaner to kill all the orphans
     KProcess::startDetached(SageSettings::self()->path().toLocalFile(),QStringList()<<QLatin1String("-cleaner"));
 
-    m_expressionQueue.clear();
+    expressionQueue().clear();
+
+    changeStatus(Status::Disable);
 }
 
-Cantor::Expression* SageSession::evaluateExpression(const QString& cmd, Cantor::Expression::FinishingBehavior behave)
+Cantor::Expression* SageSession::evaluateExpression(const QString& cmd, Cantor::Expression::FinishingBehavior behave, bool internal)
 {
     qDebug()<<"evaluating: "<<cmd;
-    SageExpression* expr=new SageExpression(this);
+    SageExpression* expr=new SageExpression(this, internal);
     expr->setFinishingBehavior(behave);
     expr->setCommand(cmd);
     expr->evaluate();
@@ -174,17 +179,6 @@ Cantor::Expression* SageSession::evaluateExpression(const QString& cmd, Cantor::
     return expr;
 }
 
-void SageSession::appendExpressionToQueue(SageExpression* expr)
-{
-    m_expressionQueue.append(expr);
-
-    if(m_expressionQueue.size()==1)
-    {
-        changeStatus(Cantor::Session::Running);
-        runFirstExpression();
-    }
-}
-
 void SageSession::readStdOut()
 {
     m_outputCache.append(QString::fromUtf8(m_process->pty()->readAll()));
@@ -275,10 +269,13 @@ void SageSession::readStdOut()
         return;
     }
 
-    if(m_isInitialized&&!m_expressionQueue.isEmpty())
+    if(m_isInitialized)
     {
-        SageExpression* expr=m_expressionQueue.first();
-        expr->parseOutput(m_outputCache);
+        if (!expressionQueue().isEmpty())
+        {
+            SageExpression* expr = static_cast<SageExpression*>(expressionQueue().first());
+            expr->parseOutput(m_outputCache);
+        }
         m_outputCache.clear();
     }
 }
@@ -288,24 +285,28 @@ void SageSession::readStdErr()
     qDebug()<<"reading stdErr";
     QString out=QLatin1String(m_process->readAllStandardError());
     qDebug()<<"err: "<<out;
-    if (!m_expressionQueue.isEmpty())
+    if (!expressionQueue().isEmpty())
     {
-        SageExpression* expr=m_expressionQueue.first();
+        SageExpression* expr = static_cast<SageExpression*>(expressionQueue().first());
         expr->parseError(out);
     }
 }
 
 void SageSession::currentExpressionChangedStatus(Cantor::Expression::Status status)
 {
-    if(status!=Cantor::Expression::Computing) //The session is ready for the next command
+    switch (status)
     {
-        SageExpression* expr=m_expressionQueue.takeFirst();
-        disconnect(expr, nullptr, this, nullptr);
-        if(m_expressionQueue.isEmpty())
-            changeStatus(Cantor::Session::Done);
-        runFirstExpression();
+        case Cantor::Expression::Done:
+        case Cantor::Expression::Error:
+            expressionQueue().removeFirst();
+            if (expressionQueue().isEmpty())
+                changeStatus(Done);
+            else
+                runFirstExpression();
+            break;
+        default:
+            break;
     }
-
 }
 
 void SageSession::processFinished(int exitCode, QProcess::ExitStatus exitStatus)
@@ -313,9 +314,10 @@ void SageSession::processFinished(int exitCode, QProcess::ExitStatus exitStatus)
     Q_UNUSED(exitCode);
     if(exitStatus==QProcess::CrashExit)
     {
-        if(!m_expressionQueue.isEmpty())
+        if(!expressionQueue().isEmpty())
         {
-            m_expressionQueue.last()->onProcessError(i18n("The Sage process crashed while evaluating this expression"));
+            static_cast<SageExpression*>(expressionQueue().last())
+                ->onProcessError(i18n("The Sage process crashed while evaluating this expression"));
         }else
         {
             //We don't have an actual command. it crashed for some other reason, just show a plain error message box
@@ -323,9 +325,10 @@ void SageSession::processFinished(int exitCode, QProcess::ExitStatus exitStatus)
         }
     }else
     {
-        if(!m_expressionQueue.isEmpty())
+        if(!expressionQueue().isEmpty())
         {
-            m_expressionQueue.last()->onProcessError(i18n("The Sage process exited while evaluating this expression"));
+            static_cast<SageExpression*>(expressionQueue().last())
+                ->onProcessError(i18n("The Sage process exited while evaluating this expression"));
         }else
         {
             //We don't have an actual command. it crashed for some other reason, just show a plain error message box
@@ -345,41 +348,56 @@ void SageSession::reportProcessError(QProcess::ProcessError e)
 
 void SageSession::runFirstExpression()
 {
-    if(!m_expressionQueue.isEmpty()&&m_isInitialized)
+    if(!expressionQueue().isEmpty())
     {
-        SageExpression* expr=m_expressionQueue.first();
-        connect(expr, SIGNAL(statusChanged(Cantor::Expression::Status)), this, SLOT(currentExpressionChangedStatus(Cantor::Expression::Status)));
-        QString command=expr->command();
-        if(command.endsWith(QLatin1Char('?')) && !command.endsWith(QLatin1String("??")))
-            command=QLatin1String("help(")+command.left(command.size()-1)+QLatin1Char(')');
-        if(command.startsWith(QLatin1Char('?')))
-            command=QLatin1String("help(")+command.mid(1)+QLatin1Char(')');
+        SageExpression* expr = static_cast<SageExpression*>(expressionQueue().first());
+        if (m_isInitialized)
+        {
+            connect(expr, SIGNAL(statusChanged(Cantor::Expression::Status)), this, SLOT(currentExpressionChangedStatus(Cantor::Expression::Status)));
 
-        qDebug()<<"writing "<<command<<" to the process";
-        m_process->pty()->write(QString(command+QLatin1String("\n\n")).toUtf8());
+            QString command=expr->command();
+            if(command.endsWith(QLatin1Char('?')) && !command.endsWith(QLatin1String("??")))
+                command=QLatin1String("help(")+command.left(command.size()-1)+QLatin1Char(')');
+            if(command.startsWith(QLatin1Char('?')))
+                command=QLatin1String("help(")+command.mid(1)+QLatin1Char(')');
+            command.append(QLatin1String("\n\n"));
+
+            qDebug()<<"writing "<<command<<" to the process";
+            expr->setStatus(Cantor::Expression::Computing);
+            m_process->pty()->write(command.toUtf8());
+        }
+        else if (expressionQueue().size() == 1)
+            // If queue contains one expression, it means, what we run this expression immediately (drop setting queued status)
+            // But we can't run expression before initializing, so mark expression, as queue
+            expr->setStatus(Cantor::Expression::Queued);
     }
 }
 
 void SageSession::interrupt()
 {
-    if(!m_expressionQueue.isEmpty())
-        m_expressionQueue.first()->interrupt();
-    m_expressionQueue.clear();
-    changeStatus(Cantor::Session::Done);
-}
+    if(!expressionQueue().isEmpty())
+    {
+        qDebug()<<"interrupting " << expressionQueue().first()->command();
+        if(m_process->state() != QProcess::NotRunning)
+        {
+#ifndef Q_OS_WIN
+            const int pid=m_process->pid();
+            kill(pid, SIGINT);
+#else
+            ; //TODO: interrupt the process on windows
+#endif
+        }
+        expressionQueue().first()->interrupt();
+        expressionQueue().removeFirst();
+        foreach (Cantor::Expression* expression, expressionQueue())
+            expression->setStatus(Cantor::Expression::Done);
+        expressionQueue().clear();
 
-void SageSession::sendSignalToProcess(int signal)
-{
-    qDebug()<<"sending signal....."<<signal;
-    //Sage spawns several child-processes. the one we are interested in is called sage-ipython.
-    //But to determine which ipython process is the one belonging to this session, we search
-    //for a bash process which is child of this sessions sage process, and only kill the
-    //ipython process which is child of the bash process
-    // the tree looks like: m_sageprocess->bash->sage-ipython
-    QString cmd=QString::fromLatin1("pkill -%1 -f -P `pgrep  -P %2 bash` .*sage-ipython.*").arg(signal).arg(m_process->pid());
-    KProcess proc(this);
-    proc.setShellCommand(cmd);
-    proc.execute();
+        qDebug()<<"done interrupting";
+    }
+
+    changeStatus(Cantor::Session::Done);
+    m_outputCache.clear();
 }
 
 void SageSession::sendInputToProcess(const QString& input)
@@ -387,17 +405,15 @@ void SageSession::sendInputToProcess(const QString& input)
     m_process->pty()->write(input.toUtf8());
 }
 
-void SageSession::waitForNextPrompt()
-{
-    m_waitingForPrompt=true;
-}
-
 void SageSession::fileCreated( const QString& path )
 {
     qDebug()<<"got a file "<<path;
-    SageExpression* expr=m_expressionQueue.first();
-    if ( expr )
-        expr->addFileResult( path );
+    if (!expressionQueue().isEmpty())
+    {
+        SageExpression* expr = static_cast<SageExpression*>(expressionQueue().first());
+        if ( expr )
+           expr->addFileResult( path );
+    }
 }
 
 void SageSession::setTypesettingEnabled(bool enable)
@@ -419,7 +435,7 @@ void SageSession::setWorksheetPath(const QString& path)
     //this variable is usually set by the "os" package when running a script
     //but when it is run in an interpreter (like sage server) it is not set
     const QString cmd = QLatin1String("__file__ = '%1'");
-    evaluateExpression(cmd.arg(path), Cantor::Expression::DeleteOnFinish);
+    evaluateExpression(cmd.arg(path), Cantor::Expression::DeleteOnFinish, true);
 }
 
 Cantor::CompletionObject* SageSession::completionFor(const QString& command, int index)
