@@ -42,7 +42,7 @@ class SageSession : public Cantor::Session
     //Note: major version -1 is treated as most current
     class VersionInfo{
       public:
-        VersionInfo(int major = -1, int minor = -1);
+        explicit VersionInfo(int major = -1, int minor = -1);
 
         //bool operator <=(VersionInfo v2);
         bool operator <(VersionInfo other) const;
@@ -61,27 +61,25 @@ class SageSession : public Cantor::Session
     };
 
 
-    SageSession( Cantor::Backend* backend);
-    ~SageSession() override;
+    explicit SageSession( Cantor::Backend* backend);
+    ~SageSession() override = default;
 
-    void login() Q_DECL_OVERRIDE;
-    void logout() Q_DECL_OVERRIDE;
+    void login() override;
+    void logout() override;
 
-    Cantor::Expression* evaluateExpression(const QString& command,Cantor::Expression::FinishingBehavior behave) Q_DECL_OVERRIDE;
+    Cantor::Expression* evaluateExpression(const QString& command,Cantor::Expression::FinishingBehavior behave = Cantor::Expression::FinishingBehavior::DoNotDelete, bool internal = false) override;
 
-    void appendExpressionToQueue(SageExpression* expr);
+    void runFirstExpression() override;
 
-    void interrupt() Q_DECL_OVERRIDE;
+    void interrupt() override;
 
-    void sendSignalToProcess(int signal);
     void sendInputToProcess(const QString& input);
-    void waitForNextPrompt();
 
-    void setTypesettingEnabled(bool enable) Q_DECL_OVERRIDE;
+    void setTypesettingEnabled(bool enable) override;
     void setWorksheetPath(const QString& path) override;
 
-    Cantor::CompletionObject* completionFor(const QString& command, int index=-1) Q_DECL_OVERRIDE;
-    QSyntaxHighlighter* syntaxHighlighter(QObject* parent) Q_DECL_OVERRIDE;
+    Cantor::CompletionObject* completionFor(const QString& command, int index=-1) override;
+    QSyntaxHighlighter* syntaxHighlighter(QObject* parent) override;
 
     VersionInfo sageVersion();
   public Q_SLOTS:
@@ -89,19 +87,17 @@ class SageSession : public Cantor::Session
     void readStdErr();
 
   private Q_SLOTS:
-    void currentExpressionChangedStatus(Cantor::Expression::Status status);
-    void processFinished(int exitCode, QProcess::ExitStatus exitStatus);
-    void reportProcessError(QProcess::ProcessError error);
+    void currentExpressionChangedStatus(Cantor::Expression::Status);
+    void processFinished(int exitCode, QProcess::ExitStatus);
+    void reportProcessError(QProcess::ProcessError);
     void fileCreated(const QString& path);
 
   private:
-    void runFirstExpression();
     void defineCustomFunctions();
     bool updateSageVersion();
   private:
     KPtyProcess* m_process;
-    QList<SageExpression*> m_expressionQueue;
-    int m_isInitialized;
+    bool m_isInitialized;
     QString m_tmpPath;
     KDirWatch m_dirWatch;
     bool m_waitingForPrompt;
