@@ -45,10 +45,8 @@
 #include "ui_settings.h"
 #include "backendchoosedialog.h"
 
-CantorShell::CantorShell()
-    : KParts::MainWindow( )
+CantorShell::CantorShell() : KParts::MainWindow(), m_part(nullptr)
 {
-    m_part=nullptr;
 
     // set the shell's ui resource file
     setXMLFile(QLatin1String("cantor_shell.rc"));
@@ -75,11 +73,6 @@ CantorShell::CantorShell()
     setDockOptions(QMainWindow::AnimatedDocks|QMainWindow::AllowTabbedDocks|QMainWindow::VerticalTabs);
 }
 
-CantorShell::~CantorShell()
-{
-
-}
-
 void CantorShell::load(const QUrl &url)
 {
     if (!m_part||!m_part->url().isEmpty() || m_part->isModified() )
@@ -130,6 +123,30 @@ void CantorShell::setupActions()
     openExample->setIcon(QIcon::fromTheme(QLatin1String("document-open")));
     actionCollection()->addAction(QLatin1String("file_example_open"), openExample);
     connect(openExample, SIGNAL(triggered()), this, SLOT(openExample()));
+
+    QAction* toPreviousTab = new QAction(i18n("Go to previous worksheet"), actionCollection());
+    actionCollection()->addAction(QLatin1String("go_to_previous_tab"), toPreviousTab);
+    actionCollection()->setDefaultShortcut(toPreviousTab, Qt::CTRL+Qt::Key_PageDown);
+    connect(toPreviousTab, &QAction::triggered, toPreviousTab, [this](){
+        const int index = m_tabWidget->currentIndex()-1;
+        if (index >= 0)
+            m_tabWidget->setCurrentIndex(index);
+        else
+            m_tabWidget->setCurrentIndex(m_tabWidget->count()-1);
+    });
+    addAction(toPreviousTab);
+
+    QAction* toNextTab = new QAction(i18n("Go to next worksheet"), actionCollection());
+    actionCollection()->addAction(QLatin1String("go_to_next_tab"), toNextTab);
+    actionCollection()->setDefaultShortcut(toNextTab, Qt::CTRL+Qt::Key_PageUp);
+    connect(toNextTab, &QAction::triggered, toNextTab, [this](){
+        const int index = m_tabWidget->currentIndex()+1;
+        if (index < m_tabWidget->count())
+            m_tabWidget->setCurrentIndex(index);
+        else
+            m_tabWidget->setCurrentIndex(0);
+    });
+    addAction(toNextTab);
 }
 
 void CantorShell::saveProperties(KConfigGroup & /*config*/)
@@ -274,27 +291,19 @@ void CantorShell::addWorksheet(const QString& backendName)
 
         if (part)
         {
-            connect(part, SIGNAL(setCaption(const QString&, const QIcon&)), this, SLOT(setTabCaption(const QString&, const QIcon&)));
-            m_parts.append(part);
-
-            //determine the icon of the backend to be added
-            Cantor::Backend* backend = nullptr;
-            for (Cantor::Backend* b : Cantor::Backend::availableBackends())
-            {
-                if (b->name() == backendName)
-                {
-                    backend = b;
-                    break;
-                }
-            }
-
-            int tab = -1;
+            //determine backend
+            Cantor::Backend* backend = Cantor::Backend::getBackend(backendName);
+            // if backend not found, part is invalid, so delete it
             if (backend)
-                tab = m_tabWidget->addTab(part->widget(), QIcon::fromTheme(backend->icon()), i18n("Session %1", sessionCount++));
-            else //should never happend but just in case we still have some bugs somewhere...
-                tab = m_tabWidget->addTab(part->widget(), i18n("Session %1", sessionCount++));
+            {
+                connect(part, SIGNAL(setCaption(QString,QIcon)), this, SLOT(setTabCaption(QString,QIcon)));
+                m_parts.append(part);
 
-            m_tabWidget->setCurrentIndex(tab);
+                int tab = m_tabWidget->addTab(part->widget(), QIcon::fromTheme(backend->icon()), i18n("Session %1", sessionCount++));
+                m_tabWidget->setCurrentIndex(tab);
+            }
+            else
+                delete part;
         }
         else
         {
