@@ -18,8 +18,8 @@
     Copyright (C) 2012 Martin Kuettler <martin.kuettler@gmail.com>
  */
 
-#include "commandentry.h"
 #include "imageresultitem.h"
+#include "commandentry.h"
 #include "lib/imageresult.h"
 #include "lib/epsresult.h"
 
@@ -27,15 +27,10 @@
 #include <QFileDialog>
 #include <QDebug>
 
-ImageResultItem::ImageResultItem(QGraphicsObject* parent)
-    : WorksheetImageItem(parent), ResultItem()
-{
-    connect(this, SIGNAL(removeResult()), parentEntry(),
-            SLOT(removeResult()));
-}
-
-ImageResultItem::~ImageResultItem()
+ImageResultItem::ImageResultItem(QGraphicsObject* parent, Cantor::Result* result)
+    : WorksheetImageItem(parent), ResultItem(result)
 {
+    update();
 }
 
 double ImageResultItem::setGeometry(double x, double y, double w)
@@ -47,25 +42,25 @@ double ImageResultItem::setGeometry(double x, double y, double w)
 
 void ImageResultItem::populateMenu(QMenu* menu, QPointF pos)
 {
-    addCommonActions(this, menu);
+    ResultItem::addCommonActions(this, menu);
 
     menu->addSeparator();
     qDebug() << "populate Menu";
     emit menuCreated(menu, mapToParent(pos));
 }
 
-ResultItem* ImageResultItem::updateFromResult(Cantor::Result* result)
+void ImageResultItem::update()
 {
-    switch(result->type()) {
+    Q_ASSERT(m_result->type() == Cantor::ImageResult::Type || m_result->type() == Cantor::EpsResult::Type);
+    switch(m_result->type()) {
     case Cantor::ImageResult::Type:
-        setImage(result->data().value<QImage>());
-        return this;
+        setImage(m_result->data().value<QImage>());
+        break;
     case Cantor::EpsResult::Type:
-        setEps(result->data().toUrl());
-        return this;
+        setEps(m_result->data().toUrl());
+        break;
     default:
-        deleteLater();
-        return create(parentEntry(), result);
+        break;
     }
 }
 
@@ -101,16 +96,3 @@ EpsRenderer* ImageResultItem::epsRenderer()
 {
     return qobject_cast<Worksheet*>(scene())->epsRenderer();
 }
-
-CommandEntry* ImageResultItem::parentEntry()
-{
-    return qobject_cast<CommandEntry*>(parentObject());
-}
-
-Cantor::Result* ImageResultItem::result()
-{
-    return parentEntry()->expression()->result();
-}
-
-
-
