@@ -23,33 +23,29 @@
 
 #include "resultitem.h"
 #include "worksheetimageitem.h"
-#include "worksheetentry.h"
-#include "epsrenderer.h"
+
+class CommandEntry;
+class EpsRenderer;
 
 class ImageResultItem : public WorksheetImageItem, public ResultItem
 {
   Q_OBJECT
   public:
-    ImageResultItem(QGraphicsObject* parent);
-    ~ImageResultItem() override;
+    explicit ImageResultItem(QGraphicsObject* parent, Cantor::Result* result);
+    ~ImageResultItem() override = default;
 
     using WorksheetImageItem::setGeometry;
-    double setGeometry(double x, double y, double w) Q_DECL_OVERRIDE;
-    void populateMenu(QMenu* menu, QPointF pos) Q_DECL_OVERRIDE;
+    double setGeometry(double x, double y, double w) override;
+    void populateMenu(QMenu* menu, QPointF pos) override;
 
-    ResultItem* updateFromResult(Cantor::Result*) Q_DECL_OVERRIDE;
+    void update() override;
 
-    QRectF boundingRect() const Q_DECL_OVERRIDE;
-    double width() const Q_DECL_OVERRIDE;
-    double height() const Q_DECL_OVERRIDE;
+    QRectF boundingRect() const override;
+    double width() const override;
+    double height() const override;
 
-    void deleteLater() Q_DECL_OVERRIDE;
+    void deleteLater() override;
     EpsRenderer* epsRenderer();
-    CommandEntry* parentEntry();
-    Cantor::Result* result() Q_DECL_OVERRIDE;
-
-  Q_SIGNALS:
-    void removeResult();
 
   protected Q_SLOTS:
     void saveResult();
