@@ -18,30 +18,24 @@
     Copyright (C) 2012 Martin Kuettler <martin.kuettler@gmail.com>
  */
 
-#include "commandentry.h"
 #include "textresultitem.h"
+#include "commandentry.h"
 #include "lib/result.h"
 #include "lib/textresult.h"
 #include "lib/latexresult.h"
 
+#include <QDebug>
+#include <QFileDialog>
 #include <QTextCursor>
 
-#include <QFileDialog>
 #include <KStandardAction>
-#include <QAction>
 #include <KLocalizedString>
-#include <QDebug>
 
-TextResultItem::TextResultItem(QGraphicsObject* parent)
-    : WorksheetTextItem(parent), ResultItem()
+TextResultItem::TextResultItem(QGraphicsObject* parent, Cantor::Result* result)
+    : WorksheetTextItem(parent), ResultItem(result)
 {
     setTextInteractionFlags(Qt::TextSelectableByMouse);
-    connect(this, SIGNAL(removeResult()), parentEntry(),
-            SLOT(removeResult()));
-}
-
-TextResultItem::~TextResultItem()
-{
+    update();
 }
 
 double TextResultItem::setGeometry(double x, double y, double w)
@@ -55,7 +49,7 @@ void TextResultItem::populateMenu(QMenu* menu, QPointF pos)
     if (!textCursor().hasSelection())
         copy->setEnabled(false);
     menu->addAction(copy);
-    addCommonActions(this, menu);
+    ResultItem::addCommonActions(this, menu);
 
     Cantor::Result* res = result();
     if (res->type() == Cantor::LatexResult::Type) {
@@ -74,27 +68,27 @@ void TextResultItem::populateMenu(QMenu* menu, QPointF pos)
     emit menuCreated(menu, mapToParent(pos));
 }
 
-ResultItem* TextResultItem::updateFromResult(Cantor::Result* result)
+void TextResultItem::update()
 {
-    switch(result->type()) {
+    Q_ASSERT(m_result->type() == Cantor::TextResult::Type || m_result->type() == Cantor::LatexResult::Type);
+    switch(m_result->type()) {
     case Cantor::TextResult::Type:
         {
             QTextCursor cursor = textCursor();
             cursor.movePosition(QTextCursor::Start);
             cursor.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
-            QString html = result->toHtml();
+            QString html = m_result->toHtml();
             if (html.isEmpty())
                 cursor.removeSelectedText();
             else
                 cursor.insertHtml(html);
-            return this;
         }
+        break;
     case Cantor::LatexResult::Type:
-        setLatex(dynamic_cast<Cantor::LatexResult*>(result));
-        return this;
+        setLatex(dynamic_cast<Cantor::LatexResult*>(m_result));
+        break;
     default:
-        deleteLater();
-        return create(parentEntry(), result);
+        break;
     }
 }
 
@@ -163,20 +157,7 @@ void TextResultItem::deleteLater()
     WorksheetTextItem::deleteLater();
 }
 
-EpsRenderer* TextResultItem::epsRenderer()
+EpsRenderer* TextResultItem::epsRenderer() const
 {
     return qobject_cast<Worksheet*>(scene())->epsRenderer();
 }
-
-CommandEntry* TextResultItem::parentEntry()
-{
-    return qobject_cast<CommandEntry*>(parentObject());
-}
-
-Cantor::Result* TextResultItem::result()
-{
-    return parentEntry()->expression()->result();
-}
-
-
-
