@@ -49,7 +49,7 @@
 #include "lib/session.h"
 #include "lib/defaulthighlighter.h"
 
-#include <config-cantorlib.h>
+#include <config-cantor.h>
 
 const double Worksheet::LeftMargin = 4;
 const double Worksheet::RightMargin = 4;
@@ -1089,7 +1089,7 @@ bool Worksheet::load(QIODevice* device)
     //file can only be loaded in a worksheet that was not eidted/modified yet (s.a. CantorShell::load())
     //in this case on the default "first entry" is available -> delete it.
     if (m_firstEntry) {
-        m_firstEntry->deleteLater();
+        delete m_firstEntry;
         m_firstEntry = nullptr;
     }
 
