@@ -21,6 +21,7 @@
 #include "worksheetentry.h"
 #include "commandentry.h"
 #include "textentry.h"
+#include "markdownentry.h"
 #include "latexentry.h"
 #include "imageentry.h"
 #include "pagebreakentry.h"
@@ -88,6 +89,8 @@ WorksheetEntry* WorksheetEntry::create(int t, Worksheet* worksheet)
     {
     case TextEntry::Type:
         return new TextEntry(worksheet);
+    case MarkdownEntry::Type:
+        return new MarkdownEntry(worksheet);
     case CommandEntry::Type:
         return new CommandEntry(worksheet);
     case ImageEntry::Type:
@@ -111,6 +114,11 @@ void WorksheetEntry::insertTextEntry()
     worksheet()->insertTextEntry(this);
 }
 
+void WorksheetEntry::insertMarkdownEntry()
+{
+    worksheet()->insertMarkdownEntry(this);
+}
+
 void WorksheetEntry::insertLatexEntry()
 {
     worksheet()->insertLatexEntry(this);
@@ -136,6 +144,11 @@ void WorksheetEntry::insertTextEntryBefore()
     worksheet()->insertTextEntryBefore(this);
 }
 
+void WorksheetEntry::insertMarkdownEntryBefore()
+{
+    worksheet()->insertMarkdownEntryBefore(this);
+}
+
 void WorksheetEntry::insertLatexEntryBefore()
 {
     worksheet()->insertLatexEntryBefore(this);
@@ -305,10 +318,10 @@ void WorksheetEntry::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 void WorksheetEntry::populateMenu(QMenu* menu, QPointF pos)
 {
     if (!worksheet()->isRunning() && wantToEvaluate())
-        menu->addAction(i18n("Evaluate Entry"), this, SLOT(evaluate()), 0);
+        menu->addAction(QIcon::fromTheme(QLatin1String("media-playback-start")), i18n("Evaluate Entry"), this, SLOT(evaluate()), 0);
 
-    menu->addAction(QIcon::fromTheme(QLatin1String("edit-delete")), i18n("Remove Entry"), this,
-                    SLOT(startRemoving()), 0);
+    menu->addAction(QIcon::fromTheme(QLatin1String("edit-delete")), i18n("Remove Entry"), this, SLOT(startRemoving()), 0);
+    menu->addSeparator();
     worksheet()->populateMenu(menu, mapToScene(pos));
 }
 
@@ -371,7 +384,6 @@ QPropertyAnimation* WorksheetEntry::sizeChangeAnimation(QSizeF s)
         layOutForWidth(size().width(), true);
         newSize = size();
     }
-    qDebug() << oldSize << newSize;
 
     QPropertyAnimation* sizeAn = new QPropertyAnimation(this, "size", this);
     sizeAn->setDuration(200);
@@ -697,7 +709,7 @@ void WorksheetEntry::showActionBar()
 
         if (wantToEvaluate()) {
             QString toolTip = i18n("Evaluate Entry");
-            m_actionBar->addButton(QIcon::fromTheme(QLatin1String("view-refresh")), toolTip,
+            m_actionBar->addButton(QIcon::fromTheme(QLatin1String("media-playback-start")), toolTip,
                                    this, SLOT(evaluate()));
         }
 
