@@ -60,8 +60,8 @@ WorksheetTextItem::WorksheetTextItem(QGraphicsObject* parent, Qt::TextInteractio
     setAcceptDrops(true);
     setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
     connect(document(), SIGNAL(contentsChanged()), this, SLOT(testSize()));
-    connect(this, SIGNAL(menuCreated(QMenu*, const QPointF&)), parent,
-            SLOT(populateMenu(QMenu*, const QPointF&)), Qt::DirectConnection);
+    connect(this, SIGNAL(menuCreated(QMenu*,QPointF)), parent,
+            SLOT(populateMenu(QMenu*,QPointF)), Qt::DirectConnection);
     connect(this, SIGNAL(deleteEntry()), parent, SLOT(startRemoving()));
     connect(this, &WorksheetTextItem::cursorPositionChanged, this, &WorksheetTextItem::updateRichTextActions);
     connect(document(), SIGNAL(undoAvailable(bool)),
@@ -364,6 +364,16 @@ bool WorksheetTextItem::isEditable()
     return textInteractionFlags() & Qt::TextEditable;
 }
 
+void WorksheetTextItem::setBackgroundColor(const QColor& color)
+{
+    m_backgroundColor = color;
+}
+
+const QColor& WorksheetTextItem::backgroundColor() const
+{
+    return m_backgroundColor;
+}
+
 bool WorksheetTextItem::richTextEnabled()
 {
     return m_richTextEnabled;
@@ -427,9 +437,6 @@ Cantor::Session* WorksheetTextItem::session()
 
 void WorksheetTextItem::keyPressEvent(QKeyEvent *event)
 {
-    if (!isEditable())
-        return;
-
     switch (event->key()) {
     case Qt::Key_Left:
         if (event->modifiers() == Qt::NoModifier && textCursor().atStart()) {
@@ -693,6 +700,15 @@ void WorksheetTextItem::insertTab()
     emit cursorPositionChanged(textCursor());
 }
 
+void WorksheetTextItem::paint(QPainter* painter, const QStyleOptionGraphicsItem* o, QWidget* w) {
+    if (m_backgroundColor.isValid()) {
+        painter->setPen(QPen(Qt::NoPen));
+        painter->setBrush(m_backgroundColor);
+        painter->drawRect(boundingRect());
+    }
+    QGraphicsTextItem::paint(painter, o, w);
+}
+
 double WorksheetTextItem::width() const
 {
     return m_size.width();
@@ -893,4 +909,12 @@ void WorksheetTextItem::setFontSize(int size)
     mergeFormatOnWordOrSelection(fmt);
 }
 
+void WorksheetTextItem::allowEditing()
+{
+    setTextInteractionFlags(Qt::TextEditorInteraction);
+}
 
+void WorksheetTextItem::denyEditing()
+{
+    setTextInteractionFlags(Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard);
+}
